@@ -31,7 +31,7 @@
 static int x1, y1, dragged;
 static int ox, oy;
 
-unsigned int mouse_x, mouse_y;
+int mouse_x, mouse_y;
 
 void
 on_exit_activate                      (GtkMenuItem     *menuitem,
@@ -127,7 +127,7 @@ void
 on_set_activate                        (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  gchar *name;
+  gchar const *name;
 
   if (GTK_CHECK_MENU_ITEM(menuitem)->active) {
     name = gtk_widget_get_name((GtkWidget *)menuitem);
@@ -136,12 +136,12 @@ on_set_activate                        (GtkMenuItem     *menuitem,
 }
 
 void
-on_set_clicked                         (GtkButton       *button,
+on_set_clicked                         (GtkToolButton   *button,
                                         gpointer         user_data)
 {
-  gchar *name;
+  gchar const *name;
 
-  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button))) {
+  if (gtk_toggle_tool_button_get_active(GTK_TOGGLE_TOOL_BUTTON(button))) {
     name = gtk_widget_get_name((GtkWidget *)button);
     switch_view (name[8] - '0');
   }
@@ -151,7 +151,8 @@ void
 on_group_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  gchar *name;
+  gchar const *name;
+
   if (GTK_CHECK_MENU_ITEM(menuitem)->active) {
     name = gtk_widget_get_name((GtkWidget *)menuitem);
     switch_color (name[6] - '0');
@@ -326,7 +327,7 @@ void
 on_set_open_ok                         (GtkButton       *button,
                                         gpointer         user_data)
 {
-  char *filename;
+  char const *filename;
 
   gtk_widget_hide (set_open);
   filename= gtk_file_selection_get_filename(GTK_FILE_SELECTION(set_open));
@@ -354,7 +355,7 @@ void
 on_config_open_ok                      (GtkButton       *button,
                                         gpointer         user_data)
 {
-  gchar *filename;
+  gchar const *filename;
   gtk_widget_hide (config_open);
   filename= gtk_file_selection_get_filename(GTK_FILE_SELECTION(config_open));
   parse_file(filename);
@@ -398,7 +399,7 @@ void
 on_add_open_ok                         (GtkButton       *button,
                                         gpointer         user_data)
 {
-  gchar *filename;
+  gchar const *filename;
   gtk_widget_hide (add_open);
   filename= gtk_file_selection_get_filename(GTK_FILE_SELECTION(add_open));
   lha_extend(filename);
@@ -555,10 +556,10 @@ on_application_drag_data_received      (GtkWidget       *widget,
                                         guint            time,
                                         gpointer         user_data)
 {
-  guchar *filename;
+  char *filename;
   int k;
 
-  filename= data->data;
+  filename= (char *) data->data;
   for (k= 0; k < data->length; ++k) {
     if (filename[k] == '\r') {
       filename[k]= '\0';
@@ -572,7 +573,7 @@ on_application_drag_data_received      (GtkWidget       *widget,
 }
 
 void
-on_unfix_clicked                       (GtkButton       *button,
+on_unfix_clicked                       (GtkToolButton   *button,
                                         gpointer         user_data)
 {
   if (config.selected && config.selected->object->fix > 1) {
