@@ -1,14 +1,73 @@
 #include <gnome.h>
 
-void
-on_exit_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
 
 gboolean
 on_application_delete_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data);
 
+void
+on_application_drag_data_received      (GtkWidget       *widget,
+                                        GdkDragContext  *drag_context,
+                                        gint             x,
+                                        gint             y,
+                                        GtkSelectionData *data,
+                                        guint            info,
+                                        guint            time,
+                                        gpointer         user_data);
+
+void
+on_open_activate                       (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_open_config_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_open_add_on_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_close_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_exit_activate                       (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_set_activate                        (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_group_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_error_list_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_unfix_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_preferences_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_about_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_set_clicked                         (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
+void
+on_unfix_clicked                       (GtkToolButton   *toolbutton,
+                                        gpointer         user_data);
+
 gboolean
 on_area_expose_event                   (GtkWidget       *widget,
                                         GdkEventExpose  *event,
@@ -19,27 +78,6 @@ on_area_configure_event                (GtkWidget       *widget,
                                         GdkEventConfigure *event,
                                         gpointer         user_data);
 
-void
-on_properties_activate                 (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_set_activate                        (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_preferences_activate                (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_about_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-gboolean
-on_area_event                          (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
 gboolean
 on_area_button_press_event             (GtkWidget       *widget,
                                         GdkEventButton  *event,
@@ -50,8 +88,9 @@ on_area_button_release_event           (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data);
 
-void
-on_open_activate                       (GtkMenuItem     *menuitem,
+gboolean
+on_area_motion_notify_event            (GtkWidget       *widget,
+                                        GdkEventMotion  *event,
                                         gpointer         user_data);
 
 void
@@ -62,15 +101,6 @@ void
 on_set_open_cancel                     (GtkButton       *button,
                                         gpointer         user_data);
 
-gboolean
-on_area_motion_notify_event            (GtkWidget       *widget,
-                                        GdkEventMotion  *event,
-                                        gpointer         user_data);
-
-void
-on_open_config_activate                (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_config_open_ok                      (GtkButton       *button,
                                         gpointer         user_data);
@@ -79,22 +109,14 @@ void
 on_config_open_cancel                  (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_set_clicked                         (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_close_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_open_add_on_activate                (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_close_errors_clicked                (GtkButton       *button,
                                         gpointer         user_data);
 
+void
+on_clear_errors_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
 void
 on_add_open_ok                         (GtkButton       *button,
                                         gpointer         user_data);
@@ -104,13 +126,24 @@ on_add_open_cancel                     (GtkButton       *button,
                                         gpointer         user_data);
 
 void
-on_preferences_clicked                 (GnomeDialog     *gnomedialog,
-                                        gint             arg1,
+on_preferences_apply                   (GnomePropertyBox *propertybox,
+                                        gint             page_num,
+                                        gpointer         user_data);
+
+gboolean
+on_preferences_close                   (GnomeDialog     *gnomedialog,
                                         gpointer         user_data);
 
 void
-on_preferences_apply                   (GnomePropertyBox *gnomepropertybox,
-                                        gint             arg1,
+on_pref_midi_toggled                   (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_pref_esound_toggled                 (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_pref_midi_player_changed            (GtkEditable     *editable,
                                         gpointer         user_data);
 
 void
@@ -129,28 +162,12 @@ void
 on_pref_ignore_colon_toggled           (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-gint
-on_preferences_close                   (GnomeDialog     *gnomedialog,
-                                        gpointer         user_data);
-
-void
-on_pref_default_palette_toggled        (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void
 on_pref_fkiss_case_toggled             (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
-on_group_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_pref_midi_toggled                   (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_pref_esound_toggled                 (GtkToggleButton *togglebutton,
+on_pref_default_palette_toggled        (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
@@ -164,45 +181,3 @@ on_pref_min_timer_changed              (GtkEditable     *editable,
 void
 on_pref_catch_drop_toggled             (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
-
-gboolean
-on_application_drag_drop               (GtkWidget       *widget,
-                                        GdkDragContext  *drag_context,
-                                        gint             x,
-                                        gint             y,
-                                        guint            time,
-                                        gpointer         user_data);
-
-void
-on_application_drag_data_received      (GtkWidget       *widget,
-                                        GdkDragContext  *drag_context,
-                                        gint             x,
-                                        gint             y,
-                                        GtkSelectionData *data,
-                                        guint            info,
-                                        guint            time,
-                                        gpointer         user_data);
-
-void
-on_pref_midi_player_changed            (GtkEditable     *editable,
-                                        gpointer         user_data);
-
-void
-on_unfix_clicked                       (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_clear_errors_clicked                (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_error_list_activate                 (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_exit_activate                       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_unfix_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
