@@ -64,7 +64,7 @@ static int cell_load(KissCell *cell, char *filename) {
 
   fread(header, 4, 1, fp);
 
-  if (strncmp(header, "KiSS", 4)) {
+  if (strncmp((char *)header, "KiSS", 4)) {
     bpp= 4;
     cell->width= header[0] + (256 * header[1]);
     cell->height= header[2] + (256 * header[3]);
