@@ -94,18 +94,18 @@ static guchar magic_palette[] =
    255, 215, 160, 255, 215, 255, 255, 255, 0,   255, 255, 80,  255, 255, 160,
    255, 255, 255 };
 
-static void fget_line(unsigned char *s, int size, FILE *stream);
-static void parse_size(guchar *entry);
-static void parse_bgcolor(guchar *entry);
-static void parse_set(guchar *entry);
-static void parse_palette(guchar *entry);
-static void parse_object(guchar *entry);
+static void fget_line(gchar *s, int size, FILE *stream);
+static void parse_size(gchar *entry);
+static void parse_bgcolor(gchar *entry);
+static void parse_set(gchar *entry);
+static void parse_palette(gchar *entry);
+static void parse_object(gchar *entry);
 static void file_done(void);
 static guchar *fake_palette(void);
 
 /* No return value, unlike fgets() */
 
-static void fget_line(unsigned char *s, int size, FILE *stream) {
+static void fget_line(gchar *s, int size, FILE *stream) {
   int k, c= '\0';
   static int prev= '\0';
 
@@ -115,7 +115,7 @@ static void fget_line(unsigned char *s, int size, FILE *stream) {
       c= fgetc(stream); /* next character instead */
     }
     if (c == EOF || c == '\n' || c == '\r') break;
-    s[k]= (unsigned char) c;
+    s[k]= c;
   }
 
   prev= c;
@@ -125,7 +125,7 @@ static void fget_line(unsigned char *s, int size, FILE *stream) {
 void parse_file(const char *filename) {
   FILE *fp;
   gchar *dirname;
-  guchar line[1024];
+  gchar line[1024];
   int k, first_view= 0, script_flag= 0, set_flag= 0;
   gint width, height;
   guint line_no= 0;
@@ -165,8 +165,8 @@ void parse_file(const char *filename) {
     set_line(line_no);
 
     if (line_no % 1000 == 0) {
-      gnome_appbar_set_progress(GNOME_APPBAR(appbar),
-                                (ftell(fp) * 1.0) / buf.st_size);
+      gnome_appbar_set_progress_percentage(GNOME_APPBAR(appbar),
+                                           (ftell(fp) * 1.0) / buf.st_size);
       /* Update GUI */
       while (gtk_events_pending()) gtk_main_iteration();
     }
@@ -191,9 +191,8 @@ void parse_file(const char *filename) {
     case '#':
       if (script_flag) {
         log_warning(_("object definition after @EventHandler"));
-      } else {
-        parse_object(line);
       }
+      parse_object(line);
       break;
     case ';':
       if (line[1] == '@') {
@@ -221,7 +220,7 @@ void parse_file(const char *filename) {
   }
   fclose(fp);
 
-  gnome_appbar_set_progress(GNOME_APPBAR(appbar), 0.0);
+  gnome_appbar_set_progress_percentage(GNOME_APPBAR(appbar), 0.0);
   file_done();
 
   /* Yes, thanks for asking, these values are arbitrary, if you know a
@@ -290,9 +289,9 @@ static void file_done(void) {
 
 /* Hence the spacing is not assumed, if it's wrong that will usually be OK */
 
-static void parse_set(guchar *entry) {
+static void parse_set(gchar *entry) {
   KissObject *object;
-  guchar *token;
+  gchar *token;
   char across[6], down[6];
   static guint objid;
   int x, y, pal= 0;
@@ -337,7 +336,7 @@ static void parse_set(guchar *entry) {
   }
 }
 
-static void parse_bgcolor(guchar *entry) {
+static void parse_bgcolor(gchar *entry) {
   unsigned int color= 0;
 
   if (sscanf(entry, "[%u", &color) != 1) {
@@ -349,7 +348,7 @@ static void parse_bgcolor(guchar *entry) {
   }
 }
 
-static void parse_size(guchar *entry) {
+static void parse_size(gchar *entry) {
   int width= 640, height= 480;
 
   if (sscanf(entry, "(%u,%u)", &width, &height) != 2) {
@@ -372,7 +371,7 @@ static guchar *fake_palette(void) {
   return palette;
 }
 
-static void parse_palette(guchar *entry) {
+static void parse_palette(gchar *entry) {
   char filename[32];
   guchar buffer[768];
   guchar *palette= NULL;
@@ -397,7 +396,7 @@ static void parse_palette(guchar *entry) {
 
   fread(buffer, 32, 1, fp);
 
-  if (strncmp(buffer, "KiSS", 4)) {
+  if (strncmp((char *) buffer, "KiSS", 4)) {
     for (j= 0; j < COLS; j++) {
       palette= fake_palette();
       for (k= 0; k < 16; ++k) {
@@ -453,7 +452,7 @@ static void parse_palette(guchar *entry) {
   fclose(fp);
 }
 
-static void parse_object(guchar *entry) {
+static void parse_object(gchar *entry) {
   unsigned int pal, vis, objid= 0, fix= 0, trans= 0;
   char pair[16], filename[32], *next;
   int digit;
