@@ -708,7 +708,7 @@ static KissActionList trigger(KissAction *action, KissActionList next) {
   case ACTION_WINDOW_SIZE:
     offset_x+= KissValue(action->args[0]);
     offset_y+= KissValue(action->args[1]);
-    gtk_widget_set_usize(get_widget(app, "scrolledwindow1"),
+    gtk_widget_set_usize(lookup_widget(app, "scrolledwindow1"),
                          config.width + offset_x, config.height + offset_y);
     break;
 
@@ -954,19 +954,21 @@ void events(KissActionList list) {
   if (depth >= MAX_DEPTH) {
     fprintf(stderr, _("French KiSS stack overflow.\n"));
     return;
-  } else {
-    depth++;
   }
+  depth++;
+
   control_flag[depth]= 1;
-  while (list != NULL) {
+  while (list != NULL && config.labels) {
     trace(list->data, depth);
     list= trigger(list->data, g_slist_next(list));
-    if (++cycles % 4096 == 0 && gtk_main_iteration_do(FALSE))
-      exit(0); /* all done */
+    if (cycles >= 65536) {
+      while (gtk_events_pending()) gtk_main_iteration();
+      cycles -= 65536;
+    } else {
+      ++cycles;
+    }
   }
+
   depth--;
-  if (depth == 0) {
-    cycles = 0; /* reset */
-  }
 }
 
