@@ -501,7 +501,7 @@ static void check_and_add(char *method, char *params, KissAction *action,
   }
 }
 
-void parse_action(guchar *text) {
+void parse_action(gchar *text) {
   gchar method[32], params[256], rest[512];
   gchar first[256], second[256], third[256];
   gchar *argv[3] = { first, second, third };
