@@ -25,7 +25,7 @@ extern GtkWidget *app, *area, *appbar, *pref_dialog, *error_clist;
 extern GtkWidget *about, *error_list, *set_open, *config_open, *add_open;
 extern GtkWidget *buttons[SETS], *items[SETS];
 
-extern unsigned int mouse_x, mouse_y;
+extern int mouse_x, mouse_y;
 
 extern int view;
 extern int global_lock; /* if KISS_PENDING, redraw will refresh rgb_buf */
@@ -65,7 +65,7 @@ typedef struct {
 } KissObject;
  
 typedef struct {
-  guchar *name;              /* Name of CEL file */
+  gchar *name;              /* Name of CEL file */
   guchar *index, *argb;      /* Image buffers */
 
   guint width, height;       /* Image size */
@@ -318,7 +318,7 @@ void lha_close(void);
 void parse_file(const char *filename);
 
 void reset_french(void);
-void parse_action(guchar *text);
+void parse_action(gchar *text);
 void events(KissActionList list);
 
 long numeric(gchar *integer);
