@@ -36,7 +36,7 @@ static GtkTargetEntry targets[1]= { { "text/uri-list", 0, 1} };
 static void set_toggle(char *toggle, gboolean value) {
   GtkWidget *widget;
 
-  widget = get_widget(pref_dialog, toggle);
+  widget = lookup_widget(pref_dialog, toggle);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), value);
 }
 
@@ -48,7 +48,7 @@ static void preferences(void) {
   set_toggle("pref_midi", prefs.midi);
 
   prefs.midi_player= gnome_config_get_string("Sound/midi_player=playmidi");
-  widget = get_widget(pref_dialog, "pref_midi_player");
+  widget = lookup_widget(pref_dialog, "pref_midi_player");
   gtk_entry_set_text(GTK_ENTRY(widget), prefs.midi_player);
 
   prefs.esound= gnome_config_get_bool("Sound/esound=true");
@@ -69,11 +69,11 @@ static void preferences(void) {
   set_toggle("pref_default_palette", prefs.default_palette);
   
   prefs.speed_factor= gnome_config_get_int("Features/speed_factor=1");
-  widget = get_widget(pref_dialog, "pref_speed_factor");
+  widget = lookup_widget(pref_dialog, "pref_speed_factor");
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(widget),(gfloat)prefs.speed_factor);
 
   prefs.min_timer= gnome_config_get_int("Features/min_timer=1");
-  widget = get_widget(pref_dialog, "pref_min_timer");
+  widget = lookup_widget(pref_dialog, "pref_min_timer");
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(widget),(gfloat)prefs.min_timer);
 
   prefs.catch_drop= gnome_config_get_bool("Features/catch_drop=false");
@@ -85,12 +85,18 @@ main (int argc, char *argv[])
 {
   GtkWidget *application;
   int i;
-  guchar widget_name[]= "show_setN";
+  gchar widget_name[]= "show_setN";
 
-  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
-  textdomain (PACKAGE);
+#ifdef ENABLE_NLS
+  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
+#endif
 
-  gnome_init ("gnomekiss", VERSION, argc, argv);
+  gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
+                      argc, argv,
+                      GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
+                      NULL);
 
   gtk_widget_push_visual(gdk_rgb_get_visual());
   gtk_widget_push_colormap(gdk_rgb_get_cmap());
@@ -108,17 +114,17 @@ main (int argc, char *argv[])
   preferences();
 
   app = application;
-  area = get_widget(app, "area");
-  appbar = get_widget(app, "appbar");
-  error_clist = get_widget(error_list, "error_clist");
+  area = lookup_widget(app, "area");
+  appbar = lookup_widget(app, "appbar");
+  error_clist = lookup_widget(error_list, "error_clist");
   gtk_clist_column_titles_passive(GTK_CLIST (error_clist));
 
   for (i= 0; i < SETS; ++i) {
     snprintf(widget_name, sizeof(widget_name), "show_set%d", i);
-    buttons[i]= get_widget(app, widget_name);
+    buttons[i]= lookup_widget(app, widget_name);
 
     snprintf(widget_name, sizeof(widget_name), "set_%d", i);
-    items[i]= get_widget(app, widget_name);
+    items[i]= lookup_widget(app, widget_name);
   }
   gtk_menu_item_activate(GTK_MENU_ITEM(items[0]));
 
@@ -126,9 +132,11 @@ main (int argc, char *argv[])
 
   gtk_widget_show (app);
 
+/* GNOME2FIXME learn to use popt apparently 
   if (argc > 1) {
     open_either(argv[1]);
   }
+*/
 
   gtk_main ();
   return 0;
