@@ -226,8 +226,8 @@ void clean_up() {
   if (config.filename!= NULL) {
     g_free(config.filename);
   }
-
   config.filename= NULL;
+
   /* free config description */
   if (config.description!= NULL) {
     g_free(config.description);
@@ -337,7 +337,7 @@ void switch_view(int set) {
   view= set;
 
   gtk_menu_item_activate(GTK_MENU_ITEM(items[view]));
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(buttons[view]), TRUE);
+  gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(buttons[view]), TRUE);
 
   /* Check all object collisions */
   g_hash_table_foreach(config.objects, check_each_object, NULL);
